Date: 07 25, 2001 10:11:55 AM

# Actions

Actions are NLP++ functions that are specialized to know about particular contexts. For example, the POST Action single assumes that a rule has successfully matched.

Historically, actions preceded NLP++, and many do not allow full NLP++ expressions as arguments. The CODE, PRE, CHECK, and POST regions all have associated actions.

Many actions, such as the PRINT actions, are superseded by the C++ -like << operator and are retained for backward compatibility.

Note: Some actions are slated for review.

## See Also

CODE Action

PRE Action

CHECK Action

POST Action

Functions